#!/bin/sh
#-----------------------------------------------------------------------
# Licensed Materials - Property of IBM
#
# IBM Tape System Library Manager
#
# (C) Copyright IBM Corp. 2004, 2020 All Rights Reserved
#
# US Government Users Restricted Rights - Use,  duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#-----------------------------------------------------------------------
#
# @version 1.8 - 20/03/18 22:03:48
#
# @brief
#
#  The following three lines have been added by UDB DB2.
#
#-----------------------------------------------------------------------

if [ ! -e ~/tslmprofile ]; then
    echo "This script must be run with TSLM user account. ('ermm' for example)"
    exit 1
fi

echo "IBM Tape System Library Manager"
echo "Licensed Materials - Property of IBM"
echo "(C) Copyright IBM Corp. 2004, 2020 All Rights Reserved"
echo

# This script must run by ermm user
if [ "$USER" != $TSLM_USER ]; then
    echo "This script must be run with $TSLM_USER account."
    exit 1
fi

# Log file for this script 
LOG=$TSLM_BASEDIR/log/tslmdbbackup.log

ONOFF="online"
# check the parameter "ON" or "OFF" only
if [[ $1 == "on" || $1 == "ON" ]]
then
    ONOFF="online"
elif [[ $1 == "off" || $1 == "OFF" ]]
then
     ONOFF=""
else
    echo "Syntax: tslmdbbackup.sh <ON | OFF> "
    exit 2
fi     

# check if the Media Manager is running for the case of off line backup
if [ -z "$ONOFF" ]
then
    MMRUN=$(ps -ef | awk '{print $8}' | grep "^$TSLM_BASEDIR/bin/MediaManager" )
    if [ ! -z "$MMRUN" ]
    then
        echo "Stop the Media Manager before the offline backup." 
        exit 2
    fi
fi

# Get definitions of backup setting
. $TSLM_BASEDIR/conf/dbuserexit.conf

# TSLMDBBACKUPDIR has the directory name for the backup files 
# check existence TSLMDBBACKUPDIR directory
touch $TSLMDBBACKUPDIR/tslmcheck
if [ $? != 0 ]
then
    echo "Cannot access to $TSLMDBBACKUPDIR directory, please check the access permission." 
    echo "Please run tslmmkarchive.sh with root user to make directories for backup."
    exit 2
fi
rm $TSLMDBBACKUPDIR/tslmcheck

echo "Starting backup ..." | tee $LOG


if [ -f $INSTHOME/sqllib/db2profile ]
then
    . $INSTHOME/sqllib/db2profile
fi


db2 "backup database ermm $ONOFF to $TSLMDBBACKUPDIR" | tee -a $LOG 2>&1

echo "Done."
exit 0
